@@ -1,3 +1,4 @@
+import math
 import re
 import textwrap
 import warnings
@@ -27,6 +28,28 @@ Exponents = Union[Pairs, Dict[Unitlike, int]]
 
 SIUNITX_NEW = 3
 SIUNITX_OLD = 2
+_SI_PREFIXES = [
+    ["yotta", "Y", "1e24"],
+    ["zetta", "Z", "1e21"],
+    ["exa", "E", "1e18"],
+    ["peta", "P", "1e15"],
+    ["tera", "T", "1e12"],
+    ["giga", "G", "1e9"],
+    ["mega", "M", "1e6"],
+    ["kilo", "k", "1e3"],
+    ["hecto", "h", "1e2"],
+    ["deka", "da", "1e1"],
+    ["deci", "d", "1e-1"],
+    ["centi", "c", "1e-2"],
+    ["milli", "m", "1e-3"],
+    ["micro", "μ", "1e-6"],
+    ["nano", "n", "1e-9"],
+    ["pico", "p", "1e-12"],
+    ["femto", "f", "1e-15"],
+    ["atto", "a", "1e-18"],
+    ["zepto", "z", "1e-21"],
+    ["yocto", "y", "1e-24"],
+]
 
 _EXTANT_UNITS = {}
 
@@ -91,43 +114,34 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
     def add(self, other: UnitInterface) -> UnitInterface:
         """Add two measurements of the same unit together.
 
-        Checks compatibility rather than type for determining "same unit". For
-        example, a calculation that outputs the dynamically created unit
-        ``kg*m*s^-2`` is equivalent to a defined expression using newtons.
-
-        :param other: Another measurement, with the same units
-        :return: A measurement with the values of the two added
+        :param other: Another measurement, with the same units.
+        :return: A measurement with the values of the two added.
         """
-        if type(other).composition != type(self).composition:
+        if type(other) != type(self):
             raise OperationError("add", type(self), type(other))
-        return type(self)(self.value + other.value * other.scale / self.scale)
+        return type(self)(self.value + other.value)
 
     def subtract(self, other: UnitInterface) -> UnitInterface:
         """Subtract a measurement of the same unit from this.
 
-        Checks compatibility rather than type for determining "same unit". For
-        example, a calculation that outputs the dynamically created unit
-        ``kg*m*s^-2`` is equivalent to a defined expression using newtons.
-
-        :param other: Another measurement, with the same units
-        :return: A measurement with the values of the two subtracted
+        :param other: Another measurement, with the same units.
+        :return: A measurement with the values of the two subtracted.
         """
-        if type(other).composition != type(self).composition:
+        if type(other) != type(self):
             raise OperationError("subtract", type(self), type(other))
-        return type(self)(self.value - other.value * other.scale / self.scale)
+        return type(self)(self.value - other.value)
 
     def equal(self, other: UnitInterface) -> bool:
         """Check if this measurement is the same value and unit of another.
 
-        Checks compatibility rather than type for determining "same unit". For
-        example, a calculation that outputs the dynamically created unit
-        ``kg*m*s^-2`` is equivalent to a defined expression using newtons.
+        :param other: Another measurement, with the same units.
+        :return: Whether these two measurements are identical.
         """
         if self is other:
             return True
-        if type(other).composition != type(self).composition:
+        if type(other) != type(self):
             return False
-        return self.value * self.scale == other.value * other.scale
+        return self.value == other.value
 
     def equivalent(self, other: UnitInterface, figs=5) -> bool:
         """Check if this measurement represents the same quantity as another,
@@ -371,6 +385,50 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
                 units.append(f"{u.abbreviation}^{{{e}}}")
         return fmt.format(value=self.value, unit=".".join(units))
 
+    def closest_si_prefix(self):
+        """Convert this value to the most natural SI prefix.
+
+        For instance, a value of 12100 meters would be changed into 12.1
+        kilometers.
+        This only works on units that have a specific name. Elementary units
+        like meters of course work, as do composite units like joules. However,
+        if a unit can only be expressed by some combination of named units
+        (say N*s) then a TypeError will be raised.
+
+        Currently ignores 10^-2 through 10^2; that is, centi through hecto.
+        These are not used nearly as often, with the exception of the
+        centimeter.
+
+        :raises TypeError: If this unit is not an SI unit.
+        :raises ValueError: If the value of this unit is too big or too small
+            to be directly expressed with an SI prefix. Instead you should
+            probably express your value as scientific notation using the base
+            unit of the dimension.
+        :return: This value expressed in the unit that requires no extra
+            scientific notation.
+        """
+        magnitude = math.log10(self.scale)
+        if magnitude != int(magnitude):
+            raise TypeError("This isn't an SI unit so prefixes can't be applied")
+        pattern = re.compile(
+            f"[{''.join(p for _, p, __ in _SI_PREFIXES)}]?" +
+            "(m|g|s|A|K|cd|mol|J|Hz|C|Pa|V|Ω)"
+        )
+        if not pattern.match(self.abbreviation):
+            raise TypeError("This isn't a base SI unit so prefixes can't be applied")
+        order = (self.value * self.scale).adjusted()
+        if order > 26 or order < -24:
+            raise ValueError("SI prefixes only cover 48 orders of magnitude")
+        mag = (order // 3) * 3
+        family = [u for u in _EXTANT_UNITS.values()
+                  if u.dimension == self.dimension and u.scale == Decimal(f"1e{mag}")]
+        if len(family) != 1:
+            # kelvin/celsius are a special case, being equal in scale
+            k = [u for u in family if u.__name__ == "kelvin"]
+            family = [k[0]]
+        converter_name = f"to_{family[0].__name__}"
+        return getattr(self, converter_name)()
+
     # @formatter:off
     # noinspection PyTypeChecker
     unit: Type[UnitInterface] = type(name, (object,), {
@@ -402,15 +460,16 @@ def make_unit(*, name: str, dimension: 'DimensionBase', scale: Scale, abbrev: st
         "__name__": name,
         "__doc__": textwrap.dedent(doc),
         # Class variables
-        "is_dimension": is_dimension,
         "abbreviation": abbrev,
         "scale": Decimal(scale),
         "instances": {},
         "dimension": dimension,
         # Methods
+        "is_dimension": is_dimension,
         "equivalent_to": equivalent,
         "sig_figs": sig_figs,
         "to_latex": to_latex,
+        "to_natural_si": closest_si_prefix,
     })
     # @formatter:on
     unit.composition = Compound(((unit, 1),))
@@ -503,30 +562,8 @@ def si_unit(*, base_unit: Type['UnitInterface'], short_doc="", skip=()) \
         doesn't get overwritten.
     :return: A dictionary between the name of the unit and the unit class.
     """
-    prefixes = [
-        ["yotta", "Y", "1e24"],
-        ["zetta", "Z", "1e21"],
-        ["exa", "E", "1e18"],
-        ["peta", "P", "1e15"],
-        ["tera", "T", "1e12"],
-        ["giga", "G", "1e9"],
-        ["mega", "M", "1e6"],
-        ["kilo", "k", "1e3"],
-        ["hecto", "h", "1e2"],
-        ["deka", "da", "1e1"],
-        ["deci", "d", "1e-1"],
-        ["centi", "c", "1e-2"],
-        ["milli", "m", "1e-3"],
-        ["micro", "μ", "1e-6"],
-        ["nano", "n", "1e-9"],
-        ["pico", "p", "1e-12"],
-        ["femto", "f", "1e-15"],
-        ["atto", "a", "1e-18"],
-        ["zepto", "z", "1e-21"],
-        ["yocto", "y", "1e-24"],
-    ]
     generated = {}
-    for prefix, short, scale in prefixes:
+    for prefix, short, scale in _SI_PREFIXES:
         if prefix in skip:
             continue
         new_scale = Decimal(scale) * base_unit.scale
@@ -829,3 +866,6 @@ class UnitInterface:
 
     def to_latex(self, siunitx_major_version=SIUNITX_NEW):
         ...
+
+    def to_natural_si(self):
+        ...
