@@ -1,25 +1,26 @@
 from decimal import Decimal
 
-from pyunitx._api import make_dimension, make_unit, make_compound_dimension, make_compound_unit
+from pyunitx._api import make_dimension, make_unit, si_unit
 
-__all__ = [
-    "Time",
-    "seconds", "minutes", "hours",
-    "days", "sidereal_days",
-    "julian_years",
-    "Frequency",
-    "hertz",
-    "rpm",
-]
 Time = make_dimension("Time")
 seconds = make_unit(
     name="seconds",
     dimension=Time,
     scale=1,
     abbrev="s",
-    doc="""The second is the SI base unit of time."""
+    doc="""\
+    The second is the SI base unit of time. As there are convenient larger 
+    units for time already, the positive SI prefixes (k, M, G) aren't used very 
+    much but the negative ones (m, μ, n) do see common use.
+    """
 )
 
+generated = si_unit(
+    base_unit=seconds,
+    short_doc=""":class:`seconds` are the base unit."""
+)
+globals().update(generated)
+
 minutes = make_unit(
     name="minutes",
     dimension=Time,
@@ -70,24 +71,9 @@ julian_years = make_unit(
     """
 )
 
-Frequency = make_compound_dimension({Time: -1}, "Frequency")
-hertz = make_compound_unit(
-    name="hertz",
-    scale=1,
-    exponents={seconds: -1},
-    abbrev="Hz",
-    doc="""\
-    The hertz represents an occurrence once per second. Most commonly,
-    this is used to measure sounds, where the occurrence is a soundwave peak 
-    passing. 
-    """
-)
-rpm = make_compound_unit(
-    name="rpm",
-    scale=1 / 60,
-    exponents={minutes: -1},
-    abbrev="rpm",
-    doc="""\
-    Revolutions per minute measure the action of a piston crank or of a wheel.
-    """
-)
+__all__ = [
+              "Time",
+              "seconds", "minutes", "hours",
+              "days", "sidereal_days",
+              "julian_years",
+          ] + list(generated.keys())
